@@ -27,6 +27,7 @@ use namespace::clean;
 
 with 'App::Parcimonie::Role::HasEncoding';
 use MooX::Options;
+use MooX::StrictConstructor;
 
 
 =head1 TYPES
@@ -119,14 +120,6 @@ option 'gnupg_already_torified' => (
     default   => sub { 0; },
 );
 
-option 'gnupg2' => (
-    documentation => q{Use GnuPG 2.1+ (default: autodetect gpg's version).},
-    isa      => 'Bool',
-    is       => 'ro',
-    required => 0,
-    default  => sub { gpg_is_v21(); },
-);
-
 has 'memory_usage' => (
     isa       => 'Memory::Usage',
     is        => 'ro',
@@ -148,12 +141,10 @@ sub BUILD {
 
     $self->record_memory_usage("[BUILD]: entering");
 
+    gpg_is_v21() or croak "parcimonie requires GnuPG 2.1 or newer";
+
     $self->keyserver_defined_on_command_line
-        or checkGpgHasDefinedKeyserver(
-            $self->gnupg_options,
-            {
-                gnupg2 => $self->gnupg2,
-            });
+        or checkGpgHasDefinedKeyserver($self->gnupg_options);
 
     if ($self->with_dbus) {
         $self->record_memory_usage("[BUILD]: starting to load D-Bus dependencies");
@@ -280,7 +271,7 @@ sub _build_gnupg_options {
     my %opts = (
         extra_args => [],
     );
-    $opts{homedir} = $self->gnupg_homedir if defined $self->gnupg_homedir;
+    $opts{homedir} = $self->gnupg_homedir->stringify if defined $self->gnupg_homedir;
     push @{$opts{extra_args}}, @{$self->gnupg_builtin_args}
         if defined $self->gnupg_builtin_args;
     push @{$opts{extra_args}}, @{$self->gnupg_extra_args}
@@ -341,7 +332,9 @@ sub tryRecvKey {
     my $self  = shift;
     my $keyid = shift;
     my $gpg_output;
-    my $gpg_error;
+    my $gpg_error = '';
+    my $filtered_gpg_error = '';
+    my $success;
 
     $self->debug(sprintf("tryRecvKey: trying to fetch %s", $keyid));
     $self->notify({ signal => 'FetchBegin', keyid => $keyid });
@@ -351,21 +344,43 @@ sub tryRecvKey {
             [ $keyid ],
             $self->gnupg_options,
             already_torified => $self->gnupg_already_torified,
-            gnupg2           => $self->gnupg2,
         );
+        $success = 1;
     } catch {
         $gpg_error = $_;
+        $success = 0;
     };
 
-    $gpg_output ||= '';
-    my $success = 0;
-    if (defined $gpg_error) {
-        warn $self->encoding->encode($gpg_error);
+    if ($success) {
+        $gpg_output ||= '';
+        $gpg_error = '';
+        $self->debug($gpg_output);
     }
     else {
-        $self->debug($gpg_output);
-        $success = 1;
-        $gpg_error = '';
+        if (defined $gpg_error) {
+            $filtered_gpg_error = $gpg_error;
+            # Filter out lines such as:
+            #   gpg: keyserver receive failed: No data
+            #   gpg: key "0123456789ABCDEF0123456789ABCDEF01234567" not found: Not found
+            # ... followed by " at /path/to/App/Parcimonie/Daemon.pm line 350"
+            $filtered_gpg_error =~ s{
+                                        ^gpg:\s+
+                                        (?:
+                                            keyserver\s+receive\s+failed:\s+No\s+data
+                                        |
+                                            key\s+"[^"\n]+"\s+not\s+found:\s+Not\s+found
+                                        )
+                                        $
+                                        (?:
+                                            [\n]
+                                            \s+at\s+[^\n]+\s+line\s+\d+[.]
+                                            $
+                                        )?
+                                        [\n]*
+                                }{}xmsg;
+            warn $self->encoding->encode($filtered_gpg_error)
+                if length($filtered_gpg_error);
+        }
     }
 
     $self->notify({
@@ -414,7 +429,6 @@ sub iterate {
     my @public_keys = gpgPublicKeys(
         $self->gnupg_options,
         already_torified => $self->gnupg_already_torified,
-        gnupg2           => $self->gnupg2,
     );
     unless (@public_keys) {
         warn "No public key was found.";
