@@ -24,7 +24,7 @@ with 'App::Parcimonie::Role::HasCodeset';
 use namespace::clean;
 
 has 'encoding' => (
-    isa        => 'Encode::Encoding',
+    isa        => 'Encode::Encoding|Encode::XS',
     is         => 'ro',
     lazy_build => 1,
 );
